@@ -311,6 +311,23 @@ def dE_rot_single(T, molecule):
     return tmp
 
 
+def dE_rot_c_dE_rot_d(T, molecule1, molecule2):
+    """Calculates dE_rot_c * (dE_rot_c + dE_rot_d), where dE_rot_c is the dimenionless difference between rotational
+    energies for molecule1, and dE_rot_d is the dimenionless difference between rotational energies for molecule2
+    Considers all transitions to be one-quantum and equiprobable
+
+    Returns:
+    dE_rot_c * dE_rot_d, where dE_rot_c is the dimenionless difference between rotational
+    energies for molecule1, and dE_rot_d is the dimenionless difference between rotational energies for molecule2
+
+    Takes as input:
+    T - the temperature of the mixture
+    molecule1 - the first molecule
+    molecule2 - the second molecule2
+    """
+    return dE_rot_single(T, molecule1) * dE_rot_single(T, molecule2)
+
+
 def dE_rot_dE_rot_full(T, molecule1, molecule2):
     """Calculates dE_rot_c * (dE_rot_c + dE_rot_d), where dE_rot_c is the dimenionless difference between rotational
     energies for molecule1, and dE_rot_d is the dimenionless difference between rotational energies for molecule2
@@ -360,6 +377,43 @@ def dE_rot_single_integral(T, idata, molecule, nokt=False):
     return dE_rot_single(T, molecule) * elastic_integral(T, 0, idata, nokt=nokt)
 
 
+def dE_rot_single_sq_integral(T, idata, molecule, nokt=False):
+    """Calculates the squared full averaging of dE_rot, where dE_rot is the dimenionless difference between rotational
+    energies
+    Considers all transitions to be one-quantum and equiprobable
+
+    Returns:
+    dE_rot, where dE_rot is the dimenionless difference between rotational energies
+
+    Takes as input:
+    T - the temperature of the mixture
+    idata - collision data for the species involved
+    molecule - the molecule
+    nokt - if True, the result is multiplied by (kT) ** (-0.5)
+    """
+    return (dE_rot_single(T, molecule) ** 2) * elastic_integral(T, 0, idata, nokt=nokt)
+
+
+def dE_rot_c_dE_rot_d_integral(T, idata, molecule1, molecule2, nokt=False):
+    """Calculates the full averaging of  dE_rot_c * (dE_rot_c + dE_rot_d), where dE_rot_c is the dimenionless difference
+    between rotational energies for molecule1, and dE_rot_d is the dimenionless difference between rotational energies
+    for molecule2
+    Considers all transitions to be one-quantum and equiprobable
+
+    Returns:
+    dE_rot_c * (dE_rot_c + dE_rot_d), where dE_rot_c is the dimenionless difference between rotational
+    energies for molecule1, and dE_rot_d is the dimenionless difference between rotational energies for molecule2
+
+    Takes as input:
+    T - the temperature of the mixture
+    idata - collision data for the species involved
+    molecule1 - the first molecule
+    molecule2 - the second molecule2
+    nokt - if True, the result is multiplied by (kT) ** (-0.5)
+    """
+    return dE_rot_c_dE_rot_d(T, molecule1, molecule2) * elastic_integral(T, 0, idata, nokt=nokt)
+
+
 def dE_rot_dE_rot_full_integral(T, idata, molecule1, molecule2, nokt=False):
     """Calculates the full averaging of  dE_rot_c * (dE_rot_c + dE_rot_d), where dE_rot_c is the dimenionless difference
     between rotational energies for molecule1, and dE_rot_d is the dimenionless difference between rotational energies
