@@ -383,9 +383,9 @@ class Molecule:
         snr = self.num_rot * (self.num_rot + 1.0)
 
         if dim == 1:
-            return kT * (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.Z_rot(T) * B)
+            return kT * (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
         else:
-            return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.Z_rot(T) * B)
+            return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
 
     def avg_vibr_energy(self, T, T1, dim=1):
         """Returns the vibrational energy, averaged over the vibrational spectrum (either dimensional or dimensionless)
@@ -461,9 +461,11 @@ class Molecule:
             B = self.rot_const / kT
             snr = self.num_rot * (self.num_rot + 1)
             if dim == 1:
-                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.Z_rot(T) * B)
+                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.rot_symmetry
+                                                                                                * self.Z_rot(T) * B)
             else:
-                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.Z_rot(T) * B)
+                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.rot_symmetry
+                                                                                    * self.Z_rot(T) * B)
         else:
             if dim == 1:
                 return self.current_raesq_dim
