@@ -289,9 +289,9 @@ class Molecule_sts:
         snr = self.num_rot * (self.num_rot + 1.0)
 
         if dim == 1:
-            return kT * (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.Z_rot(T) * B)
+            return kT * (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
         else:
-            return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.Z_rot(T) * B)
+            return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
 
     def rot_avg_energy_sq(self, T, dim=1):
         """Returns the squared rotational energy, averaged over the rotational spectrum
@@ -310,9 +310,11 @@ class Molecule_sts:
             B = self.rot_const / kT
             snr = self.num_rot * (self.num_rot + 1)
             if dim == 1:
-                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.Z_rot(T) * B)
+                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.rot_symmetry
+                                                                                                * self.Z_rot(T) * B)
             else:
-                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.Z_rot(T) * B)
+                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.rot_symmetry
+                                                                                    * self.Z_rot(T) * B)
         else:
             if dim == 1:
                 return self.current_raesq_dim
